pub struct CachedToken {
pub access_token: String,
pub api_server: String,
pub expires_at: OffsetDateTime,
}Expand description
Pre-existing token state that can be passed to TokenManager::new to
skip the initial token refresh when a valid cached token is available.
Fields
access_token: StringBearer access token from a previous session.
api_server: StringAPI server URL that was returned alongside this access token.
expires_at: OffsetDateTimeWhen this access token expires.